Encry
-----

This is a simple, and fairly insecure Encryption module for python

If you want something to put in chat messages to lots of people this is perfect

To see the path to the file simply do:
	>>>From Encry import getpath
	>>>print getpath('Encry.py')

From there you can use Encry like it's ment to be used.